#ifndef CLASSES_H_INCLUDED
#define CLASSES_H_INCLUDED
#include <vector>
#include <string>

class Termek
{
private:
    std::string cim;
    int celTav;
public:
    Termek(): cim(""), celTav(0) {}
    Termek(std::string s, int d): cim(s), celTav(d) {}
    int getCelTav() const {return celTav;}
    std::string getCim() const {return cim;}
};


class Motor
{
private:
    bool mukodik;
public:
    Motor(): mukodik(false) {}
    void start() {mukodik=true;}
    void stop() {mukodik=false;}
    bool mukodik_e() const {return mukodik;}
};

class UzemanyagTank
{
private:
    double aktMennyiseg;
    double kapacitas;
public:
    enum Errors{RosszMennyiseg,RosszKapacitas};
    UzemanyagTank(double m, double k): aktMennyiseg(m), kapacitas(k)
        {if (m<=0) throw RosszMennyiseg; if(k<=0) throw RosszKapacitas;}
    void uzemanyagotTolt(double m) {if(m>0) aktMennyiseg+=m; else throw RosszMennyiseg;}
    void uzemanyagotFogyaszt(double m);
    double getUzemanyag() const {return aktMennyiseg;}
    double getKapacitas() const {return kapacitas;}

};

enum Szin{Kek,Sarga};

class Jarmu{
private:
    double fogyasztas;
    int termekKapacitas;
    Szin szine;
    Motor motor;
    UzemanyagTank tank;
    std::vector<Termek> rakomany;
    int akt; //aktualisan szallitando termek indexe
public:
    enum Errors{RosszFogyasztas,RosszTermekKapacitas,RosszTavolsag,TankolniKell,RosszMennyiseg,Tultoltes};
    Jarmu(double fogy, int tkap, Szin s, double umenny, double ukap);
    bool eleg_az_uzemanyag(double dist);
    void indits() {motor.start();}
    void allj() {motor.stop();}
    void menet(double d);
    void tolt(double menny);
    bool felveszTermek(Termek t);
    Termek atadTermek();
    int kovTavHossz();
    int getTermekKapacitas() const {return termekKapacitas; }
    double getAktTank() const {return tank.getUzemanyag();}
    double getTankKapacitas() const {return tank.getKapacitas();}


};

class Futar
{
private:
    Jarmu* kocsi;
public:
    Futar(Jarmu* a) {kocsi=a;}
    void szallit(const std::vector<Termek>& termekek);
};
#endif // CLASSES_H_INCLUDED
